"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.useMyket = useMyket;

var _react = require("react");

var _bridge = _interopRequireDefault(require("./bridge"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Recommended to use 'myket' object for Class Component
 * @date 2/1/2023 - 1:43:34 PM
 *
 * @type {{ connect(rsaKey: string): any; disconnect(): any; purchaseProduct: (sku: string, developerPayload: string) => any; consumePurchase: (purchase: any) => any; queryPurchaseProduct: (querySkuDetails: boolean, moreSkus: {}) => any; }}
 */
const myket = {
  connect(rsaKey) {
    return _bridge.default.connect(rsaKey);
  },

  disconnect() {
    return _bridge.default.disconnect();
  },

  enableDebugging: _bridge.default.enableDebugging,
  purchaseProduct: _bridge.default.purchaseProduct,
  consumePurchase: _bridge.default.consumePurchase,
  queryPurchaseProduct: _bridge.default.queryInventory
};
/**
 * Recommended to use 'useMyket' for Functional Component
 * @date 2/1/2023 - 1:47:16 PM
 *
 * @export
 * @param {(string | null)} rsaKey - base64 public RSA key provided from myket store panel 
 * @returns {{ connect(rsaKey: string): any; disconnect(): any; purchaseProduct: (sku: string, developerPayload: string) => any; consumePurchase: (purchase: any) => any; queryPurchaseProduct: (querySkuDetails: boolean, moreSkus: {}) => any; }}
 */

function useMyket(rsaKey) {
  (0, _react.useEffect)(() => {
    myket.connect(rsaKey);
    return () => {
      myket.disconnect();
    };
  }, []);
  return myket;
}

var _default = myket;
exports.default = _default;
//# sourceMappingURL=index.js.map